@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,9 +25,7 @@ class ImageRecord(AbstractModel):
 
     def __init__(self):
         """
-        :param Value: 图片翻译结果
-        :type Value: list of ItemValue
-        """
+        :param Value: 图片翻译结果\n        :type Value: list of ItemValue\n        """
         self.Value = None
 
 
@@ -43,7 +41,7 @@ class ImageRecord(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -54,15 +52,7 @@ class ImageTranslateRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SessionUuid: 唯一id，返回时原样返回
-        :type SessionUuid: str
-        :param Scene: doc:文档扫描
-        :type Scene: str
-        :param Data: 图片数据的Base64字符串，图片大小上限为4M，建议对源图片进行一定程度压缩
-        :type Data: str
-        :param Source: 源语言，支持语言列表：<li> auto：自动识别（识别为一种语言）</li> <li>zh：简体中文</li> <li>zh-TW：繁体中文</li> <li>en：英语</li> <li>ja：日语</li> <li>ko：韩语</li> <li>ru：俄语</li> <li>fr：法语</li> <li>de：德语</li> <li>it：意大利语</li> <li>es：西班牙语</li> <li>pt：葡萄牙语</li> <li>ms：马来西亚语</li> <li>th：泰语</li><li>vi：越南语</li>
-        :type Source: str
-        :param Target: 目标语言，各源语言的目标语言支持列表如下：
+        :param SessionUuid: 唯一id，返回时原样返回\n        :type SessionUuid: str\n        :param Scene: doc:文档扫描\n        :type Scene: str\n        :param Data: 图片数据的Base64字符串，图片大小上限为4M，建议对源图片进行一定程度压缩\n        :type Data: str\n        :param Source: 源语言，支持语言列表：<li> auto：自动识别（识别为一种语言）</li> <li>zh：简体中文</li> <li>zh-TW：繁体中文</li> <li>en：英语</li> <li>ja：日语</li> <li>ko：韩语</li> <li>ru：俄语</li> <li>fr：法语</li> <li>de：德语</li> <li>it：意大利语</li> <li>es：西班牙语</li> <li>pt：葡萄牙语</li> <li>ms：马来西亚语</li> <li>th：泰语</li><li>vi：越南语</li>\n        :type Source: str\n        :param Target: 目标语言，各源语言的目标语言支持列表如下：
 <li>zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
 <li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
 <li>en（英语）：zh（中文）、ja（日语）、ko（韩语）、ru（俄语）、fr（法语）、de（德语）、it（意大利语）、es（西班牙语）、pt（葡萄牙语）、ms（马来语）、th（泰语）、vi（越南语）</li>
@@ -76,11 +66,7 @@ class ImageTranslateRequest(AbstractModel):
 <li>pt：葡萄牙语：zh（中文）、en（英语）</li>
 <li>ms：马来西亚语：zh（中文）、en（英语）</li>
 <li>th：泰语：zh（中文）、en（英语）</li>
-<li>vi：越南语：zh（中文）、en（英语）</li>
-        :type Target: str
-        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
-        :type ProjectId: int
-        """
+<li>vi：越南语：zh（中文）、en（英语）</li>\n        :type Target: str\n        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0\n        :type ProjectId: int\n        """
         self.SessionUuid = None
         self.Scene = None
         self.Data = None
@@ -101,7 +87,7 @@ class ImageTranslateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -112,17 +98,7 @@ class ImageTranslateResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SessionUuid: 请求的SessionUuid返回
-        :type SessionUuid: str
-        :param Source: 源语言
-        :type Source: str
-        :param Target: 目标语言
-        :type Target: str
-        :param ImageRecord: 图片翻译结果，翻译结果按识别的文本每一行独立翻译，后续会推出按段落划分并翻译的版本
-        :type ImageRecord: :class:`tencentcloud.tmt.v20180321.models.ImageRecord`
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SessionUuid: 请求的SessionUuid返回\n        :type SessionUuid: str\n        :param Source: 源语言\n        :type Source: str\n        :param Target: 目标语言\n        :type Target: str\n        :param ImageRecord: 图片翻译结果，翻译结果按识别的文本每一行独立翻译，后续会推出按段落划分并翻译的版本\n        :type ImageRecord: :class:`tencentcloud.tmt.v20180321.models.ImageRecord`\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SessionUuid = None
         self.Source = None
         self.Target = None
@@ -138,13 +114,6 @@ class ImageTranslateResponse(AbstractModel):
             self.ImageRecord = ImageRecord()
             self.ImageRecord._deserialize(params.get("ImageRecord"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ItemValue(AbstractModel):
@@ -154,19 +123,7 @@ class ItemValue(AbstractModel):
 
     def __init__(self):
         """
-        :param SourceText: 识别出的源文
-        :type SourceText: str
-        :param TargetText: 翻译后的译文
-        :type TargetText: str
-        :param X: X坐标
-        :type X: int
-        :param Y: Y坐标
-        :type Y: int
-        :param W: 宽度
-        :type W: int
-        :param H: 高度
-        :type H: int
-        """
+        :param SourceText: 识别出的源文\n        :type SourceText: str\n        :param TargetText: 翻译后的译文\n        :type TargetText: str\n        :param X: X坐标\n        :type X: int\n        :param Y: Y坐标\n        :type Y: int\n        :param W: 宽度\n        :type W: int\n        :param H: 高度\n        :type H: int\n        """
         self.SourceText = None
         self.TargetText = None
         self.X = None
@@ -187,7 +144,7 @@ class ItemValue(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -198,11 +155,7 @@ class LanguageDetectRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Text: 待识别的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败。单次请求的文本长度需要低于2000。
-        :type Text: str
-        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
-        :type ProjectId: int
-        """
+        :param Text: 待识别的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败。单次请求的文本长度需要低于2000。\n        :type Text: str\n        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0\n        :type ProjectId: int\n        """
         self.Text = None
         self.ProjectId = None
 
@@ -215,7 +168,7 @@ class LanguageDetectRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -227,11 +180,7 @@ class LanguageDetectResponse(AbstractModel):
     def __init__(self):
         """
         :param Lang: 识别出的语言种类，参考语言列表
-<li> zh : 中文 </li> <li> en : 英文 </li><li> jp : 日语 </li> <li> kr : 韩语 </li><li> de : 德语 </li><li> fr : 法语 </li><li> es : 西班牙文 </li> <li> it : 意大利文 </li><li> tr : 土耳其文 </li><li> ru : 俄文 </li><li> pt : 葡萄牙文 </li><li> vi : 越南文 </li><li> id : 印度尼西亚文 </li><li> ms : 马来西亚文 </li><li> th : 泰文 </li>
-        :type Lang: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+<li> zh : 中文 </li> <li> en : 英文 </li><li> jp : 日语 </li> <li> kr : 韩语 </li><li> de : 德语 </li><li> fr : 法语 </li><li> es : 西班牙文 </li> <li> it : 意大利文 </li><li> tr : 土耳其文 </li><li> ru : 俄文 </li><li> pt : 葡萄牙文 </li><li> vi : 越南文 </li><li> id : 印度尼西亚文 </li><li> ms : 马来西亚文 </li><li> th : 泰文 </li>\n        :type Lang: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Lang = None
         self.RequestId = None
 
@@ -239,13 +188,6 @@ class LanguageDetectResponse(AbstractModel):
     def _deserialize(self, params):
         self.Lang = params.get("Lang")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class SpeechTranslateRequest(AbstractModel):
@@ -255,27 +197,7 @@ class SpeechTranslateRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SessionUuid: 一段完整的语音对应一个SessionUuid
-        :type SessionUuid: str
-        :param Source: 音频中的语言类型，支持语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
-        :type Source: str
-        :param Target: 翻译目标语言类型，支持的语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
-        :type Target: str
-        :param AudioFormat: pcm : 146   speex : 16779154   mp3 : 83886080
-        :type AudioFormat: int
-        :param Seq: 语音分片的序号，从0开始
-        :type Seq: int
-        :param IsEnd: 是否最后一片语音分片，0-否，1-是
-        :type IsEnd: int
-        :param Data: 语音分片内容进行 Base64 编码后的字符串。音频内容需包含有效并可识别的文本信息。
-        :type Data: str
-        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
-        :type ProjectId: int
-        :param Mode: 识别模式，该参数已废弃
-        :type Mode: str
-        :param TransType: 该参数已废弃
-        :type TransType: int
-        """
+        :param SessionUuid: 一段完整的语音对应一个SessionUuid\n        :type SessionUuid: str\n        :param Source: 音频中的语言类型，支持语言列表<li> zh : 中文 </li> <li> en : 英文 </li>\n        :type Source: str\n        :param Target: 翻译目标语言类型，支持的语言列表<li> zh : 中文 </li> <li> en : 英文 </li>\n        :type Target: str\n        :param AudioFormat: pcm : 146   speex : 16779154   mp3 : 83886080\n        :type AudioFormat: int\n        :param Seq: 语音分片的序号，从0开始\n        :type Seq: int\n        :param IsEnd: 是否最后一片语音分片，0-否，1-是\n        :type IsEnd: int\n        :param Data: 语音分片内容进行 Base64 编码后的字符串。音频内容需包含有效并可识别的文本信息。\n        :type Data: str\n        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0\n        :type ProjectId: int\n        :param Mode: 识别模式，该参数已废弃\n        :type Mode: str\n        :param TransType: 该参数已废弃\n        :type TransType: int\n        """
         self.SessionUuid = None
         self.Source = None
         self.Target = None
@@ -304,7 +226,7 @@ class SpeechTranslateRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -315,25 +237,7 @@ class SpeechTranslateResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param SessionUuid: 请求的SessionUuid直接返回
-        :type SessionUuid: str
-        :param RecognizeStatus: 语音识别状态 1-进行中 0-完成
-        :type RecognizeStatus: int
-        :param SourceText: 识别出的原文
-        :type SourceText: str
-        :param TargetText: 翻译出的译文
-        :type TargetText: str
-        :param Seq: 第几个语音分片
-        :type Seq: int
-        :param Source: 原语言
-        :type Source: str
-        :param Target: 目标语言
-        :type Target: str
-        :param VadSeq: 当请求的Mode参数填写bvad是，启动VadSeq。此时Seq会被设置为后台vad（静音检测）后的新序号，而VadSeq代表客户端原始Seq值
-        :type VadSeq: int
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param SessionUuid: 请求的SessionUuid直接返回\n        :type SessionUuid: str\n        :param RecognizeStatus: 语音识别状态 1-进行中 0-完成\n        :type RecognizeStatus: int\n        :param SourceText: 识别出的原文\n        :type SourceText: str\n        :param TargetText: 翻译出的译文\n        :type TargetText: str\n        :param Seq: 第几个语音分片\n        :type Seq: int\n        :param Source: 原语言\n        :type Source: str\n        :param Target: 目标语言\n        :type Target: str\n        :param VadSeq: 当请求的Mode参数填写bvad是，启动VadSeq。此时Seq会被设置为后台vad（静音检测）后的新序号，而VadSeq代表客户端原始Seq值\n        :type VadSeq: int\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.SessionUuid = None
         self.RecognizeStatus = None
         self.SourceText = None
@@ -355,13 +259,6 @@ class SpeechTranslateResponse(AbstractModel):
         self.Target = params.get("Target")
         self.VadSeq = params.get("VadSeq")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TextTranslateBatchRequest(AbstractModel):
@@ -390,9 +287,7 @@ id：印尼语
 th：泰语
 ms：马来西亚语
 ar：阿拉伯语
-hi：印地语
-        :type Source: str
-        :param Target: 目标语言，各源语言的目标语言支持列表如下
+hi：印地语\n        :type Source: str\n        :param Target: 目标语言，各源语言的目标语言支持列表如下
 
 <li> zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
 <li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
@@ -411,13 +306,7 @@ hi：印地语
 <li>th（泰语）：zh（中文）、en（英语）</li>
 <li>ms（马来语）：zh（中文）、en（英语）</li>
 <li>ar（阿拉伯语）：en（英语）</li>
-<li>hi（印地语）：en（英语）</li>
-        :type Target: str
-        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
-        :type ProjectId: int
-        :param SourceTextList: 待翻译的文本列表，批量接口可以以数组方式在一次请求中填写多个待翻译文本。文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度总和需要低于2000。
-        :type SourceTextList: list of str
-        """
+<li>hi（印地语）：en（英语）</li>\n        :type Target: str\n        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0\n        :type ProjectId: int\n        :param SourceTextList: 待翻译的文本列表，批量接口可以以数组方式在一次请求中填写多个待翻译文本。文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度总和需要低于2000。\n        :type SourceTextList: list of str\n        """
         self.Source = None
         self.Target = None
         self.ProjectId = None
@@ -434,7 +323,7 @@ hi：印地语
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -445,15 +334,7 @@ class TextTranslateBatchResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Source: 源语言，详见入参Target
-        :type Source: str
-        :param Target: 目标语言，详见入参Target
-        :type Target: str
-        :param TargetTextList: 翻译后的文本列表
-        :type TargetTextList: list of str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param Source: 源语言，详见入参Target\n        :type Source: str\n        :param Target: 目标语言，详见入参Target\n        :type Target: str\n        :param TargetTextList: 翻译后的文本列表\n        :type TargetTextList: list of str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Source = None
         self.Target = None
         self.TargetTextList = None
@@ -465,13 +346,6 @@ class TextTranslateBatchResponse(AbstractModel):
         self.Target = params.get("Target")
         self.TargetTextList = params.get("TargetTextList")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TextTranslateRequest(AbstractModel):
@@ -481,9 +355,7 @@ class TextTranslateRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param SourceText: 待翻译的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度需要低于2000。
-        :type SourceText: str
-        :param Source: 源语言，支持：
+        :param SourceText: 待翻译的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度需要低于2000。\n        :type SourceText: str\n        :param Source: 源语言，支持：
 auto：自动识别（识别为一种语言）
 zh：简体中文
 zh-TW：繁体中文
@@ -502,9 +374,7 @@ id：印尼语
 th：泰语
 ms：马来西亚语
 ar：阿拉伯语
-hi：印地语
-        :type Source: str
-        :param Target: 目标语言，各源语言的目标语言支持列表如下
+hi：印地语\n        :type Source: str\n        :param Target: 目标语言，各源语言的目标语言支持列表如下
 
 <li> zh（简体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
 <li>zh-TW（繁体中文）：en（英语）、ja（日语）、ko（韩语）、fr（法语）、es（西班牙语）、it（意大利语）、de（德语）、tr（土耳其语）、ru（俄语）、pt（葡萄牙语）、vi（越南语）、id（印尼语）、th（泰语）、ms（马来语）</li>
@@ -523,13 +393,7 @@ hi：印地语
 <li>th（泰语）：zh（中文）、en（英语）</li>
 <li>ms（马来语）：zh（中文）、en（英语）</li>
 <li>ar（阿拉伯语）：en（英语）</li>
-<li>hi（印地语）：en（英语）</li>
-        :type Target: str
-        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
-        :type ProjectId: int
-        :param UntranslatedText: 用来标记不希望被翻译的文本内容，如句子中的特殊符号、人名、地名等；每次请求只支持配置一个不被翻译的单词；仅支持配置人名、地名等名词，不要配置动词或短语，否则会影响翻译结果。
-        :type UntranslatedText: str
-        """
+<li>hi（印地语）：en（英语）</li>\n        :type Target: str\n        :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0\n        :type ProjectId: int\n        :param UntranslatedText: 用来标记不希望被翻译的文本内容，如句子中的特殊符号、人名、地名等；每次请求只支持配置一个不被翻译的单词；仅支持配置人名、地名等名词，不要配置动词或短语，否则会影响翻译结果。\n        :type UntranslatedText: str\n        """
         self.SourceText = None
         self.Source = None
         self.Target = None
@@ -548,7 +412,7 @@ hi：印地语
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -559,15 +423,7 @@ class TextTranslateResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TargetText: 翻译后的文本
-        :type TargetText: str
-        :param Source: 源语言，详见入参Target
-        :type Source: str
-        :param Target: 目标语言，详见入参Target
-        :type Target: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
+        :param TargetText: 翻译后的文本\n        :type TargetText: str\n        :param Source: 源语言，详见入参Target\n        :type Source: str\n        :param Target: 目标语言，详见入参Target\n        :type Target: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.TargetText = None
         self.Source = None
         self.Target = None
@@ -578,11 +434,4 @@ class TextTranslateResponse(AbstractModel):
         self.TargetText = params.get("TargetText")
         self.Source = params.get("Source")
         self.Target = params.get("Target")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
